Blocking API mirror of the top-level async API.
Structs
- Client
- Blocking client carrying reusable fetch defaults.
- Client
Builder - Builder for
Client.
Functions
- crawl
- Crawl a site and collect all results (blocking).
- crawl_
each - Crawl a site, invoking
on_pagefor each result as it arrives (blocking). - extract_
json - Fetch a URL and return structured JSON (blocking).
- fetch
- Fetch a single page via the embedded Servo engine (blocking).
- map
- Discover URLs on a site via sitemaps and link extraction (blocking).
- markdown
- Fetch a URL and return readable Markdown (blocking).
- text
- Fetch a URL and return plain text (
document.body.innerText) (blocking).