fetch

Function fetch 

pub fn fetch(opts: FetchOptions) -> Result<Page>
Fetch a single page via the embedded Servo engine.

The first call spawns a persistent engine thread that lives for the process lifetime. If the engine thread panics, this returns Error::Engine.